@@ -17,25 +17,29 @@
 *
 */
 
-const Util = imports.util;
 const Gio = imports.gi.Gio;
-const Gst = imports.gi.Gst;
 const GLib = imports.gi.GLib;
+const Gst = imports.gi.Gst;
+const Gtk = imports.gi.Gtk;
+const Lang = imports.lang;
 
 const MainWindow = imports.mainWindow;
 const Preferences = imports.preferences;
+const Util = imports.util;
+
 const SIGINT = 2;
 const SIGTERM = 15;
 
 let application = null;
 let settings = null;
 
+
 const Application = new Lang.Class({
     Name: 'Application',
     Extends: Gtk.Application,
 
     _init: function() {
-        this.parent({ application_id: "org.gnome.SoundRecorder"}); 
+        this.parent({ application_id: pkg.name }); 
         GLib.set_application_name(_("SoundRecorder"));         
     },
     
@@ -49,7 +53,6 @@ const Application = new Lang.Class({
         section.append(_("About"), 'app.about');
         section.append(_("Quit"),'app.quit');
         this.set_app_menu(menu);
-        
         let preferences = new Gio.SimpleAction({ name: 'preferences' });
         preferences.connect('activate', Lang.bind(this,
             function() {
@@ -81,7 +84,6 @@ const Application = new Lang.Class({
         Gst.init(null, 0);
         this._initAppMenu();
         application = this;
-        
         settings = new Gio.Settings({ schema: 'org.gnome.gnome-sound-recorder' });
         /* Translators: "Recordings" here refers to the name of the directory where the application places files */
         let path = GLib.build_filenamev([GLib.get_home_dir(), _("Recordings")]);
@@ -98,7 +100,6 @@ const Application = new Lang.Class({
     onWindowDestroy: function() {
         if (MainWindow.wave.pipeline)
             MainWindow.wave.pipeline.set_state(Gst.State.NULL);
-            
         if (MainWindow._record.pipeline) 
             MainWindow._record.pipeline.set_state(Gst.State.NULL);
         
@@ -113,8 +114,8 @@ const Application = new Lang.Class({
             function(widget, response) {
                 preferencesDialog.widget.destroy();
             }));
-    },
-    
+    },   
+        
     getPreferences: function() {
         let set = settings.get_int("media-type-preset");
         return set;
@@ -155,7 +156,7 @@ const Application = new Lang.Class({
         aboutDialog.copyright = 'Copyright ' + String.fromCharCode(0x00A9) + ' 2013' + String.fromCharCode(0x2013) + 'Meg Ford';
         aboutDialog.license_type = Gtk.License.GPL_2_0;
         aboutDialog.logo_icon_name = 'audio-input-microphone';
-        aboutDialog.version = '3.12.2';
+        aboutDialog.version = pkg.version;
         aboutDialog.website = 'http://live.gnome.org/GnomeSoundRecorder';
         aboutDialog.wrap_license = true;
         aboutDialog.modal = true;
