@@ -17,14 +17,14 @@
  *
  */
 
-imports.gi.versions.Gst = '1.0';
-
 const _ = imports.gettext.gettext;
 const Gio = imports.gi.Gio;
+const GLib = imports.gi.GLib;
 const Gst = imports.gi.Gst;
 const GstAudio = imports.gi.GstAudio;
 const GstPbutils = imports.gi.GstPbutils;
-
+const Gtk = imports.gi.Gtk;
+const Lang = imports.lang;
 const Mainloop = imports.mainloop;
 
 const Application = imports.application;
@@ -38,12 +38,20 @@ const PipelineStates = {
     NULL: 3
 }; 
 
+const ErrState = {
+    OFF: 0,
+    ON: 1
+}
+
+let errorDialogState;
+
 const _TENTH_SEC = 100000000;
  
  const Play = new Lang.Class({
     Name: "Play",
 
     _playPipeline: function() {
+        errorDialogState = ErrState.OFF;
         let uri = this._fileToPlay.get_uri();
         this.play = Gst.ElementFactory.make("playbin", "play");
         this.play.set_property("uri", uri);
@@ -78,8 +86,8 @@ const _TENTH_SEC = 100000000;
         this.playState = PipelineStates.PLAYING;
                 
         if (this.ret == Gst.StateChangeReturn.FAILURE) {
-            this._showErrorDialog(_('Unable to play recording')); 
-            this.onEndOfStream();
+            this._showErrorDialog(_('Unable to play recording'));
+            errorDialogState = ErrState.ON;
         } else if (this.ret == Gst.StateChangeReturn.SUCCESS) {        
             MainWindow.view.setVolume(); 
         }
@@ -114,7 +122,10 @@ const _TENTH_SEC = 100000000;
             this.timeout = null;
         }
         
-        MainWindow.wave.endDrawing();
+        if (MainWindow.wave != null)
+            MainWindow.wave.endDrawing();
+            
+        errorDialogState = ErrState.OFF;
     },
     
     onEndOfStream: function() {
@@ -129,29 +140,23 @@ const _TENTH_SEC = 100000000;
         case Gst.MessageType.EOS:               
             this.onEndOfStream(); 
             break;
+            
+        case Gst.MessageType.WARNING:               
+            let warningMessage = message.parse_warning()[0];
+            log(warningMessage.toString()); 
+            break;
                 
         case Gst.MessageType.ERROR:
-            let errorMessage = message.parse_error();
-            this._showErrorDialog(errorMessage);              
-            this.play.set_state(Gst.State.NULL);
-            this.playState = PipelineStates.STOPPED;
-            this.playBus.remove_signal_watch();
-            this._updateTime();
-                                    
-            if (this.timeout) {
-                GLib.source_remove(this.timeout);
-                this.timeout = null;
-            }
-                
-            MainWindow.wave.endDrawing();           
+            let errorMessage = message.parse_error()[0];
+            this._showErrorDialog(errorMessage.toString());              
+            errorDialogState = ErrState.ON;       
             break;
             
         case Gst.MessageType.ASYNC_DONE:
             if (this.sought) {
                 this.play.set_state(this._lastState);                    
                 MainWindow.view.setProgressScaleSensitive();
-            }
-                    
+            }       
             this.updatePosition();
             break; 
                 
@@ -190,7 +195,10 @@ const _TENTH_SEC = 100000000;
  
         this.runTime = absoluteTime- this.baseTime;
         let approxTime = Math.round(this.runTime/_TENTH_SEC);
-        MainWindow.wave._drawEvent(approxTime);
+        
+        if (MainWindow.wave != null) {
+            MainWindow.wave._drawEvent(approxTime);
+        }
         
         return true;
     },
@@ -210,7 +218,6 @@ const _TENTH_SEC = 100000000;
                 this._updateTime));    
         }
     },
-
     
     setVolume: function(value) {
         this.play.set_volume(GstAudio.StreamVolumeFormat.CUBIC, value);
@@ -222,23 +229,25 @@ const _TENTH_SEC = 100000000;
     },
     
     _showErrorDialog: function(errorStrOne, errorStrTwo) {
-        let errorDialog = new Gtk.MessageDialog ({ destroy_with_parent: true,
-                                                   buttons: Gtk.ButtonsType.OK,
-                                                   message_type: Gtk.MessageType.WARNING });
+        if (errorDialogState == ErrState.OFF) {
+            let errorDialog = new Gtk.MessageDialog ({ destroy_with_parent: true,
+                                                       buttons: Gtk.ButtonsType.OK,
+                                                       message_type: Gtk.MessageType.WARNING });
 
-        if (errorStrOne != null) {
-            errorDialog.set_property('text', errorStrOne);
+            if (errorStrOne != null)
+                errorDialog.set_property('text', errorStrOne);
+             
+            if (errorStrTwo != null)
+                errorDialog.set_property('secondary-text', errorStrTwo);
+
+            errorDialog.set_transient_for(Gio.Application.get_default().get_active_window());
+            errorDialog.connect ('response', Lang.bind(this,
+                function() {
+                    errorDialog.destroy();
+                    this.onEndOfStream();
+                }));
+            errorDialog.show();
         }
-         
-        if (errorStrTwo != null)
-            errorDialog.set_property('secondary-text', errorStrTwo);
-
-        errorDialog.set_transient_for(Gio.Application.get_default().get_active_window());
-        errorDialog.connect ('response', Lang.bind(this,
-            function() {
-                errorDialog.destroy();
-            }));
-        errorDialog.show();
     }
 });
    
