@@ -17,8 +17,6 @@
  *
  */
 
-imports.gi.versions.Gst = '1.0';
-
 const _ = imports.gettext.gettext;
 const Gio = imports.gi.Gio;
 const GLib = imports.gi.GLib;
@@ -26,8 +24,9 @@ const GObject = imports.gi.GObject;
 const Gst = imports.gi.Gst;
 const GstAudio = imports.gi.GstAudio;
 const GstPbutils = imports.gi.GstPbutils;
+const Gtk = imports.gi.Gtk;
 const Pango = imports.gi.Pango;
-
+const Lang = imports.lang;
 const Mainloop = imports.mainloop;
 const Signals = imports.signals;
 
@@ -42,12 +41,20 @@ const PipelineStates = {
     STOPPED: 2
 };
 
+const ErrState = {
+    OFF: 0,
+    ON: 1
+}
+
 const _TENTH_SEC = 100000000;
+
+let errorDialogState;
    
 const Record = new Lang.Class({
     Name: "Record",
     
     _recordPipeline: function() {
+        errorDialogState = ErrState.OFF;
         this.baseTime = 0;
         this._view = MainWindow.view; 
         this._buildFileName = new BuildFileName();
@@ -57,6 +64,7 @@ const Record = new Lang.Class({
         
         if (this.initialFileName == -1) {
             this._showErrorDialog(_('Unable to create Recordings directory.'));
+            errorDialogState = ErrState.ON;
             this.onEndOfStream();
         }
                       
@@ -65,6 +73,7 @@ const Record = new Lang.Class({
         
         if(this.srcElement == null) {
           this._showErrorDialog(_('Your audio capture settings are invalid.'));
+          errorDialogState = ErrState.ON;
           this.onEndOfStream();
           return;
         }
@@ -102,8 +111,8 @@ const Record = new Lang.Class({
                     }
                 }
             }));
-        let ebinProfile = this.ebin.set_property("profile", this._mediaProfile);
         this.pipeline.add(this.ebin);
+        let ebinProfile = this.ebin.set_property("profile", this._mediaProfile);
         let srcpad = this.ebin.get_static_pad("src");
         this.filesink = Gst.ElementFactory.make("filesink", "filesink");
         this.filesink.set_property("location", this.initialFileName);
@@ -111,6 +120,7 @@ const Record = new Lang.Class({
         
         if (!this.pipeline || !this.filesink) {
             this._showErrorDialog(_('Not all elements could be created.'));
+            errorDialogState = ErrState.ON;
             this.onEndOfStream();
         }
             
@@ -121,6 +131,7 @@ const Record = new Lang.Class({
         
         if (!srcLink || !levelLink || !ebinLink) {
             this._showErrorDialog(_('Not all of the elements were linked'));
+            errorDialogState = ErrState.ON;
             this.onEndOfStream();
         }
         
@@ -145,6 +156,7 @@ const Record = new Lang.Class({
         
         if (this._mediaProfile == -1) {
             this._showErrorDialog(_('No Media Profile was set.'));
+            errorDialogState = ErrState.ON;
         }
         
         if (!this.pipeline || this.pipeState == PipelineStates.STOPPED )
@@ -154,8 +166,9 @@ const Record = new Lang.Class({
         this.pipeState = PipelineStates.PLAYING;
         
         if (ret == Gst.StateChangeReturn.FAILURE) {
-            this._showErrorDialog(_('Unable to set the pipeline \n to the recording state')); 
-            this._buildFileName.getTitle().delete_async(GLib.PRIORITY_DEFAULT, null, null);
+            this._showErrorDialog(_('Unable to set the pipeline \n to the recording state'));
+            errorDialogState = ErrState.ON;
+            this._buildFileName.getTitle().delete_async(GLib.PRIORITY_DEFAULT, null, null); 
         } else {        
             MainWindow.view.setVolume(); 
         }
@@ -180,10 +193,12 @@ const Record = new Lang.Class({
     onEndOfStream: function() { 
         this.pipeline.set_state(Gst.State.NULL);
         this.pipeState = PipelineStates.STOPPED;
-        if (this.recordBus) {
+        
+        if (this.recordBus) 
 	        this.recordBus.remove_signal_watch();
-        }
+	        
         this._updateTime(); 
+        errorDialogState = ErrState.OFF;
     },
         
     _onMessageReceived: function(message) {
@@ -204,8 +219,9 @@ const Record = new Lang.Class({
                    
                 if (description != null)
                     errorTwo = description; 
-                       
-                this._showErrorDialog(errorOne, errorTwo);                       
+    
+                this._showErrorDialog(errorOne, errorTwo); 
+                errorDialogState = ErrState.ON;                          
             }
                 
             let s = message.get_structure();
@@ -243,10 +259,16 @@ const Record = new Lang.Class({
         case Gst.MessageType.EOS:                  
             this.onEndOfStream(); 
             break;
+            
+        case Gst.MessageType.WARNING:               
+            let warningMessage = message.parse_warning()[0];
+            log(warningMessage.toString()); 
+            break;
                                         
         case Gst.MessageType.ERROR:
             let errorMessage = message.parse_error();
-            this._showErrorDialog(errorMessage);              
+            this._showErrorDialog(errorMessage.toString()); 
+            errorDialogState = ErrState.ON;               
             break;
         }
     },
@@ -258,25 +280,27 @@ const Record = new Lang.Class({
     },
     
     _showErrorDialog: function(errorStrOne, errorStrTwo) {
-        let errorDialog = new Gtk.MessageDialog ({ modal: true,
-                                                   destroy_with_parent: true,
-                                                   buttons: Gtk.ButtonsType.OK,
-                                                   message_type: Gtk.MessageType.WARNING });
-        if (errorStrOne != null) {
-            errorDialog.set_property('text', errorStrOne);
-        }
-         
-        if (errorStrTwo != null)
-            errorDialog.set_property('secondary-text', errorStrTwo);
-            
-        errorDialog.set_transient_for(Gio.Application.get_default().get_active_window());
-        errorDialog.connect('response', Lang.bind(this,
-            function() {
-                errorDialog.destroy();
-                MainWindow.view.onRecordStopClicked();
-                this.onEndOfStream();
-            }));
-        errorDialog.show();
+        if (errorDialogState == ErrState.OFF) {
+            let errorDialog = new Gtk.MessageDialog ({ modal: true,
+                                                       destroy_with_parent: true,
+                                                       buttons: Gtk.ButtonsType.OK,
+                                                       message_type: Gtk.MessageType.WARNING });
+            if (errorStrOne != null) {
+                errorDialog.set_property('text', errorStrOne);
+            }
+             
+            if (errorStrTwo != null)
+                errorDialog.set_property('secondary-text', errorStrTwo);
+                
+            errorDialog.set_transient_for(Gio.Application.get_default().get_active_window());
+            errorDialog.connect('response', Lang.bind(this,
+                function() {
+                    errorDialog.destroy();
+                    MainWindow.view.onRecordStopClicked();
+                    this.onEndOfStream();
+                }));
+            errorDialog.show();
+        } 
     } 
 });
 
